@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+from dataclasses import dataclass
 
 from typing import (
     Dict,
@@ -13,6 +14,7 @@ from typing import (
     runtime_checkable,
     Callable,
     overload,
+    TypeVar,
 )
 
 Callback = Callable[..., Any]
@@ -56,7 +58,7 @@ class StreamUrls(TypedDict):
     www: Go2RtcEndpoint
 
 
-class CameraInput(TypedDict, total=False):
+class CameraInput(TypedDict):
     _id: str
     name: str
     roles: List["CameraRoles"]
@@ -93,7 +95,7 @@ class CameraInformation(TypedDict):
 CameraType = Literal["camera", "doorbell"]
 
 
-class BaseCamera(TypedDict, total=False):
+class BaseCamera(TypedDict):
     _id: str
     nativeId: Optional[str]
     pluginId: str
@@ -119,6 +121,187 @@ class Camera(BaseCamera):
 
 
 # camera types
+@dataclass
+class BaseState:
+    timestamp: int
+    lastTriggered: int
+
+
+@dataclass
+class MotionSetEvent:
+    state: bool
+
+
+@dataclass
+class AudioSetEvent:
+    state: bool
+
+
+@dataclass
+class ObjectSetEvent:
+    state: bool
+    detections: List[str]
+
+
+@dataclass
+class LightSetEvent:
+    state: bool
+
+
+@dataclass
+class DoorbellSetEvent:
+    state: bool
+
+
+@dataclass
+class SirenSetEvent:
+    state: bool
+
+
+@dataclass
+class BatterySetEvent:
+    state: int
+
+
+@dataclass
+class DeviceSetEvent:
+    pass
+
+
+@dataclass
+class LightState(BaseState, LightSetEvent):
+    pass
+
+
+@dataclass
+class MotionState(BaseState, MotionSetEvent):
+    pass
+
+
+@dataclass
+class AudioState(BaseState, AudioSetEvent):
+    pass
+
+
+@dataclass
+class DoorbellState(BaseState, DoorbellSetEvent):
+    pass
+
+
+@dataclass
+class SirenState(BaseState, SirenSetEvent):
+    pass
+
+
+@dataclass
+class ObjectState(BaseState, ObjectSetEvent):
+    pass
+
+
+@dataclass
+class BatteryState(BaseState, BatterySetEvent):
+    pass
+
+
+State = Union[
+    LightState,
+    MotionState,
+    AudioState,
+    DoorbellState,
+    SirenState,
+    ObjectState,
+    BatteryState,
+]
+
+T = TypeVar(
+    "T",
+    LightState,
+    MotionState,
+    AudioState,
+    DoorbellState,
+    SirenState,
+    ObjectState,
+    BatteryState,
+)
+
+
+class StateValues(Protocol):
+    light: LightState
+    motion: MotionState
+    audio: AudioState
+    object: ObjectState
+    doorbell: DoorbellState
+    siren: SirenState
+    battery: BatteryState
+
+
+CameraStateCallbacks = Dict[str, Callable[[T], None]]
+
+StateValue = Union[
+    LightState,
+    MotionState,
+    AudioState,
+    DoorbellState,
+    SirenState,
+    ObjectState,
+    BatteryState,
+]
+
+OnSetEvent = Union[
+    LightSetEvent,
+    MotionSetEvent,
+    AudioSetEvent,
+    DoorbellSetEvent,
+    SirenSetEvent,
+    BatterySetEvent,
+    ObjectSetEvent,
+]
+
+OnChangeCallback = Callable[[T, T], None]
+
+
+class CameraSource(Protocol):
+    async def is_prebuffering(self, type: str) -> bool: ...
+    async def get_prebuffer_raw_url(self, type: str) -> Optional[str]: ...
+    async def get_stream_info(self) -> Optional[Dict[str, Any]]: ...
+
+
+class CameraDelegate(ABC):
+    @abstractmethod
+    async def snapshot_request(self, request_id: str) -> bytes:
+        pass
+
+    @abstractmethod
+    async def prepare_stream(self, request_id: str) -> None:
+        pass
+
+    @abstractmethod
+    async def on_offer(self, request_id: str, sdp: str) -> str:
+        pass
+
+    @abstractmethod
+    async def on_candidates(self, request_id: str, candidates: str) -> None:
+        pass
+
+    @abstractmethod
+    async def reboot(self) -> None:
+        pass
+
+
+class CameraPrebufferDelegate(ABC):
+    @abstractmethod
+    async def is_prebuffering(self, source_name: str, type: str) -> bool:
+        pass
+
+    @abstractmethod
+    async def get_prebuffer_raw_url(self, source_name: str, type: str) -> Optional[str]:
+        pass
+
+    @abstractmethod
+    async def get_stream_info(self, source_name: str) -> Optional[Dict[str, Any]]:
+        pass
+
+
 CameraExtension = Literal[
     "hub",
     "prebuffer",
@@ -154,7 +337,7 @@ class CameraConfigWithSources(BaseCameraConfig):
 
 
 class CameraConfigWithDelegate(BaseCameraConfig):
-    delegate: Any
+    delegate: Optional[CameraDelegate]
 
 
 CameraConfig = Union[CameraConfigWithSources, CameraConfigWithDelegate]
@@ -177,7 +360,6 @@ class JsonBaseSchema(TypedDict):
     defaultValue: Optional[Union[str, int, bool]]
 
 
-# Erweitertes Basis-Schema für Plugins
 class PluginJsonBaseSchema(JsonBaseSchema):
     store: Optional[bool]
     onGet: Any
